@@ -1353,9 +1353,13 @@ def load_data_from_np_or_mat_file(file_name, attr_name=None):
         data = np.load(file_name)
     elif file_name.endswith(".npz"):
         data = np.load(file_name)
+        if attr_name not in data:
+            raise Exception(f"{attr_name} not available in {file_name}, choices are {list(data.keys())}")
         data = data[attr_name]
     elif file_name.endswith(".mat"):  # .mat
         data = hdf5storage.loadmat(file_name)
+        if attr_name not in data:
+            raise Exception(f"{attr_name} not available in {file_name}, choices are {list(data.keys())}")
         data = data[attr_name]
     else:
         print("Load_data_from_np_or_mat_file() error: file extension must be .npy, .npz or .mat")
@@ -1441,7 +1445,8 @@ class SessionForBenchmark:
     From a directory content including a yaml config file, will read ground truth + infered data
     """
 
-    def __init__(self, dir_to_explore, inferences_to_benchmark):
+    def __init__(self, dir_to_explore, inferences_to_benchmark, predictions_keywords_dict,
+                 default_predictions_threshold):
         """
 
         Args:
@@ -1452,6 +1457,9 @@ class SessionForBenchmark:
         self.dir_to_explore = dir_to_explore
         self.valid = False
         self.session_id = os.path.basename(dir_to_explore)
+        self.predictions_keywords_dict = predictions_keywords_dict
+        self.default_predictions_threshold = default_predictions_threshold
+        self.cells_in_ground_truth = None
 
         # 2d binary array (n_cells * n_frames)
         self.ground_truth = None
@@ -1489,6 +1497,11 @@ class SessionForBenchmark:
             if "file_name" not in inference_data:
                 raise Exception(f"No file_name given in inference data {inference_id} of {yaml_file_name}")
             inference_file_name = inference_data["file_name"]
+
+            # we remove the file from the list of filenames
+            if inference_file_name in file_names:
+                file_names.remove(inference_file_name)
+
             inference_file_name = os.path.join(dir_to_explore, inference_file_name)
 
             if inference_id == "groundtruth":
@@ -1497,7 +1510,7 @@ class SessionForBenchmark:
                     raise Exception(f"{os.path.basename(inference_file_name)} format not yet "
                                     f"implemented for ground truth"
                                     f"in {yaml_file_name}")
-
+                self.cells_in_ground_truth = cells
                 # so far ground truth file has to be in cinac format
                 self.extract_data_from_cinac_file(cinac_file=inference_file_name, cells_to_add=cells,
                                                   for_ground_truth=True, label=None)
@@ -1532,7 +1545,7 @@ class SessionForBenchmark:
                     # get a 2d array of shape n_cells*n_frames
                     inference_neuronal_data = load_data_from_np_or_mat_file(file_name=inference_file_name,
                                                                             attr_name=attr_name)
-                    if "to_bin" in inference_data:
+                    if "to_bin" in inference_data and inference_data['to_bin']:
                         # bining the data, useful for caiman output for exemple
                         inference_neuronal_data = bin_raster(inference_neuronal_data)
                     if "traces_file_name" in inference_data:
@@ -1549,11 +1562,25 @@ class SessionForBenchmark:
                 else:
                     print(f"Format of {os.path.basename(inference_file_name)} not supported")
 
-        # build_spike_nums_dur(spike_nums, peak_nums)
+        # then if the list of prediction keywords is not None, we list the files to find some
+        if len(predictions_keywords_dict) > 0:
+            for pred_keyword, inference_id in predictions_keywords_dict.items():
+                for file_name in file_names:
+                    if pred_keyword in file_name:
+                        inference_file_name = os.path.join(dir_to_explore, file_name)
+                        prediction_threshold = default_predictions_threshold
+                        predictions = load_data_from_np_or_mat_file(file_name=inference_file_name,
+                                                                    attr_name="predictions")
 
-        # # sys.stderr.write(f"{analysis_args_from_yaml}")
-        # for arg_name, args_content in yaml_data.items():
-        #     pass
+                        # then we produce the raster dur based on the predictions using threshold the prediction_threshold
+                        raster_dur = np.zeros(predictions.shape, dtype="int8")
+
+                        for cell in np.arange(len(predictions)):
+                            raster_dur[cell, predictions[cell] >= prediction_threshold] = 1
+                        self.inferences_raster_dict[inference_id] = [raster_dur, predictions]
+                        # we put the same cells as in GT
+                        self.cells_by_inference[inference_id] = self.cells_in_ground_truth
+                        break
 
         self.valid = True
 
@@ -1668,6 +1695,10 @@ def benchmark_neuronal_activity_inferences(inferences_dir, results_path):
     # list of inference_id, if empty with evaluate all inference, otherwise just those in the list
     inferences_to_benchmark = []
     sessions_to_exclude = []
+    # dict that contains as keys a list of keyword allowing to selecting predictions file automatically
+    # the value is the inference_id
+    predictions_keywords_dict = {}
+    default_predictions_threshold = 0.5
     config_yaml_file = [f for f in file_names_in_root if (not f.startswith(".") and f.endswith(".yaml"))]
     if len(config_yaml_file) > 0:
         config_yaml_file = os.path.join(inferences_dir, config_yaml_file[0])
@@ -1675,6 +1706,8 @@ def benchmark_neuronal_activity_inferences(inferences_dir, results_path):
             yaml_data = yaml.load(stream, Loader=yaml.FullLoader)
         inferences_to_benchmark = yaml_data.get("inferences_to_benchmark", [])
         sessions_to_exclude = yaml_data.get("sessions_to_exclude", [])
+        predictions_keywords_dict = yaml_data.get("predictions_keywords", {})
+        default_predictions_threshold = yaml_data.get("predictions_threshold", 0.5)
 
     directories = [os.path.join(inferences_dir, d) for d in directories if not d.startswith(".")]
 
@@ -1686,7 +1719,9 @@ def benchmark_neuronal_activity_inferences(inferences_dir, results_path):
             continue
 
         session_for_benchmark = SessionForBenchmark(dir_to_explore=dir_to_explore,
-                                                    inferences_to_benchmark=inferences_to_benchmark)
+                                                    inferences_to_benchmark=inferences_to_benchmark,
+                                                    predictions_keywords_dict=predictions_keywords_dict,
+                                                    default_predictions_threshold=default_predictions_threshold)
         if session_for_benchmark.valid:
             sessions_for_benchmark.append(session_for_benchmark)
             inference_ids.extend(session_for_benchmark.get_inference_ids())
