@@ -209,7 +209,7 @@ class CinacPredictor:
                         predictions = predict_transient_from_model(cinac_recording=cinac_recording,
                                                                    cell=cell, model=model, overlap_value=overlap_value,
                                                                    use_data_augmentation=use_data_augmentation,
-                                                                   n_frames=n_frames)
+                                                                   n_frames=n_frames, buffer=1, pixels_around=0)
                         # print(f"### cinac_predictor predict(): np.sum(predictions) {np.sum(predictions)}")
                         if len(predictions.shape) == 1:
                             predictions_by_cell[original_cell] = predictions
@@ -755,6 +755,7 @@ def activity_predictions_from_cinac_files(cinac_dir_name, results_path,
             elif "npy" in output_file_format:
                 np.save(os.path.join(results_path, file_name + ".npy"), predictions_for_all_cells)
 
+
 def evaluate_cell_type_predictions(cinac_dir_name, cell_type_yaml_file, results_path,
                                    json_file_name, weights_file_name, save_cell_type_distribution):
     """
