@@ -904,7 +904,7 @@ def read_cell_type_categories_yaml_file(yaml_file, using_multi_class):
             predicted_cell_type = None
             if (multi_class_arg is None and using_multi_class == 1) or (multi_class_arg is False):
                 for cell_type_category, category_dict in args_content.items():
-                    if "predicted_celll_type" in category_dict:
+                    if "predicted_cell_type" in category_dict:
                         predicted_cell_type = cell_type_category
             for cell_type_category, category_dict in args_content.items():
                 if (predicted_cell_type is not None) and (predicted_cell_type == cell_type_category) and \
